Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(971)

Unified Diff: src/gpu/gl/GrGLContext.h

Issue 2288033003: Turned on SkSL->GLSL compiler (Closed)
Patch Set: changed <iostream> to <ostream> Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gyp/sksl.gyp ('k') | src/gpu/gl/GrGLContext.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/gl/GrGLContext.h
diff --git a/src/gpu/gl/GrGLContext.h b/src/gpu/gl/GrGLContext.h
index 6016f6859a35e5cbfd9213dd043d6b85813e7f2d..8207ac89b0092d0b7ed3d392bf31f3ef29f73f33 100644
--- a/src/gpu/gl/GrGLContext.h
+++ b/src/gpu/gl/GrGLContext.h
@@ -15,6 +15,9 @@
#include "GrGLUtil.h"
struct GrContextOptions;
+namespace SkSL {
+ class Compiler;
+}
/**
* Encapsulates information about an OpenGL context including the OpenGL
@@ -39,6 +42,8 @@ public:
const GrGLExtensions& extensions() const { return fInterface->fExtensions; }
+ virtual ~GrGLContextInfo() {}
+
protected:
struct ConstructorArgs {
const GrGLInterface* fInterface;
@@ -64,7 +69,7 @@ protected:
};
/**
* Extension of GrGLContextInfo that also provides access to GrGLInterface.
*/
class GrGLContext : public GrGLContextInfo {
public:
@@ -76,8 +81,16 @@ public:
const GrGLInterface* interface() const { return fInterface; }
+ SkSL::Compiler* compiler() const;
+
+ ~GrGLContext() override;
+
private:
- GrGLContext(const ConstructorArgs& args) : INHERITED(args) {}
+ GrGLContext(const ConstructorArgs& args)
+ : INHERITED(args)
+ , fCompiler(nullptr) {}
+
+ mutable SkSL::Compiler* fCompiler;
typedef GrGLContextInfo INHERITED;
};
« no previous file with comments | « gyp/sksl.gyp ('k') | src/gpu/gl/GrGLContext.cpp » ('j') | no next file with comments »
@@ -64,7 +69,7 @@ protected:
};
/**
- * Extension of GrGLContextInfo that also provides access to GrGLInterface.
+ * Extension of GrGLContextInfo that also provides access to GrGLInterface and SkSL::Compiler.
*/
class GrGLContext : public GrGLContextInfo {

Powered by Google App Engine
This is Rietveld 408576698